@@ -341,7 +341,7 @@ readCivEDICCS <- function(path,
         testJKprefix <- c("JK") # have any jk prefix values here that are applicable for this dataset
         weights <- NULL # default value
 
-        for (i in 1:length(testJKprefix)) {
+        for (i in seq_along(testJKprefix)) {
           ujkz <- unique(tolower(grep(paste0("^", "(", testJKprefix[i], ")", "[1-9]"), c(names(processedData$dataList$student), names(processedData$dataList$teacher)), value = TRUE, ignore.case = TRUE)))
           ujkz <- gsub(tolower(testJKprefix[i]), "", ujkz, fixed = TRUE) # remove jk to leave the numeric values
 
@@ -410,7 +410,7 @@ readCivEDICCS <- function(path,
         testJKprefix <- c("JK.TOTWGTT") # have any jk prefix values here that are applicable for this dataset
         weights <- NULL # default value
 
-        for (i in 1:length(testJKprefix)) {
+        for (i in seq_along(testJKprefix)) {
           ujkz <- unique(tolower(grep(paste0("^", "(", testJKprefix[i], ")", "[1-9]"), c(names(processedData$dataList$student), names(processedData$dataList$teacher)), value = TRUE, ignore.case = TRUE)))
           ujkz <- gsub(tolower(testJKprefix[i]), "", ujkz, fixed = TRUE) # remove jk to leave the numeric values
 
@@ -478,7 +478,7 @@ readCivEDICCS <- function(path,
         testJKprefix <- c("JK", "JK.TOTWGTCH") # have any jk prefix values here that are applicable for this dataset
         weights <- NULL # default value
 
-        for (i in 1:length(testJKprefix)) {
+        for (i in seq_along(testJKprefix)) {
           ujkz <- unique(tolower(grep(paste0("^", "(", testJKprefix[i], ")", "[1-9]"), c(names(processedData$dataList$student), names(processedData$dataList$teacher)), value = TRUE, ignore.case = TRUE)))
           ujkz <- gsub(tolower(testJKprefix[i]), "", ujkz, fixed = TRUE) # remove jk to leave the numeric values
 
@@ -1468,7 +1468,7 @@ getICCSCountryName <- function(countryCode) {
 
   lookupNames <- vector(mode = "character", length = length(countryCode))
 
-  for (i in 1:length(countryCode)) {
+  for (i in seq_along(countryCode)) {
     testName <- cntryCodeDF[cntryCodeDF$cntryCode == countryCode[i], "cntryName"]
 
     if (length(testName) == 0) { # test if no value found
@@ -1485,7 +1485,7 @@ exportCivEDICCSToCSV <- function(folderPath, exportPath, cntryCodes, dataSet, gr
   sdfList <- readCivEDICCS(folderPath, cntryCodes, dataSet = dataSet, gradeLvl = gradeLvl, ...)
 
   if (inherits(sdfList, "edsurvey.data.frame.list")) {
-    for (i in 1:length(sdfList$datalist)) {
+    for (i in seq_along(sdfList$datalist)) {
       sdf <- sdfList$datalist[[i]]
       cntry <- sdf$country
       cat(paste(cntry, "working.\n"))
