@@ -38,7 +38,7 @@
 #' \code{edsurvey.data.frame.list} if multiple countries specified
 #'
 #' @seealso \code{\link{readNAEP}}, \code{\link{readTIMSS}}, and \code{\link{getData}}
-#' @author Tom Fink and Jeppe Bundsgaard (updated for 2018)
+#' @author Tom Fink and Jeppe Bundsgaard (updated for 2018 and 2023)
 #'
 #' @example man/examples/readICILS.R
 #'
@@ -222,7 +222,7 @@ readICILS <- function(path,
         testJKprefix <- c("srwgt") # have any jk prefix values here that are applicable for this dataset
         weights <- NULL # default value
 
-        for (i in 1:length(testJKprefix)) {
+        for (i in seq_along(testJKprefix)) {
           ujkz <- unique(tolower(grep(paste0("^", "(", testJKprefix[i], ")", "[1-9]"), c(names(processedData$dataList$student), names(processedData$dataList$teacher)), value = TRUE, ignore.case = TRUE)))
           ujkz <- gsub(tolower(testJKprefix[i]), "", ujkz, fixed = TRUE) # remove jk to leave the numeric values
 
@@ -299,7 +299,7 @@ readICILS <- function(path,
         testJKprefix <- c("trwgt") # have any jk prefix values here that are applicable for this dataset
         weights <- NULL # default value
 
-        for (i in 1:length(testJKprefix)) {
+        for (i in seq_along(testJKprefix)) {
           ujkz <- unique(tolower(grep(paste0("^", "(", testJKprefix[i], ")", "[1-9]"), c(names(processedData$dataList$student), names(processedData$dataList$teacher)), value = TRUE, ignore.case = TRUE)))
           ujkz <- gsub(tolower(testJKprefix[i]), "", ujkz, fixed = TRUE) # remove jk to leave the numeric values
 
@@ -339,7 +339,8 @@ readICILS <- function(path,
         "LOGICALLY NOT APPLICABLE", "MISSING", "NOT ADMINISTERED/MISSING BY DESIGN",
         "PRESENTED BUT NOT ANSWERED/INVALID", "NOT REACHED", "NOT APPLICABLE", "NOT STATED",
         "NOT ADMINISTERED OR MISSING BY DESIGN", "PRESENTED BUT NOT ANSWERED OR INVALID",
-        "(Missing)"
+        "(Missing)",
+        "NOT ADMINISTERED/NOT SCORED/SCORE OUT OF RANGE"
       )
 
       processedData$survey <- "ICILS"
@@ -392,16 +393,17 @@ convertICILSYearCode <- function(yrCode) {
   yrTest <- tolower(sort(unique(yrCode)))
   yrTest[yrTest %in% "i1"] <- 2013
   yrTest[yrTest %in% "i2"] <- 2018
-
+  yrTest[yrTest %in% "i3"] <- 2023
+  
   return(yrTest)
 }
 
-# contributor: Jeppe Bundsgaard: updates for ICILS 2018
+# contributor: Jeppe Bundsgaard: updates for ICILS 2018 and 2023
 getICILSYearCodes <- function() {
   # retrieve the ICILS years based on their filenaming structure
 
-  yrVals <- c("i1", "i2")
-  names(yrVals) <- c(2013, 2018)
+  yrVals <- c("i1", "i2", "i3")
+  names(yrVals) <- c(2013, 2018, 2023)
 
   return(yrVals)
 }
@@ -651,7 +653,7 @@ exportICILSToCSV <- function(folderPath, exportPath, cntryCodes, dataSet, ...) {
   sdfList <- readICILS(folderPath, cntryCodes, dataSet, ...)
 
   if (inherits(sdfList, "edsurvey.data.frame.list")) {
-    for (i in 1:length(sdfList$datalist)) {
+    for (i in seq_along(sdfList$datalist)) {
       sdf <- sdfList$datalist[[i]]
       cntry <- sdf$country
 
@@ -678,7 +680,7 @@ exportICILSToCSV <- function(folderPath, exportPath, cntryCodes, dataSet, ...) {
 # get the full country name to aide the user, so they won't have to track them down.
 # cntryCode should be the 3 character country code vector defined in the data filename scheme (e.g., usa = United States, swe = Sweden)
 # if a match is not found, this funtion will return a character value indicating it is unknown '(unknown) CountryCode: xxx'
-# contributor: Jeppe Bundsgaard: updates for ICILS 2018
+# contributor: Jeppe Bundsgaard: updates for ICILS 2018 and 2023
 getICILSCountryName <- function(countryCode) {
   cntryCodeDF <- data.frame(
     cntryCode = c(
@@ -694,7 +696,20 @@ getICILSCountryName <- function(countryCode) {
       "svk", "svn",
       "tha", "tur",
       "fin", "fra", "ita", "kaz", "lux", "prt",
-      "usa", "ury", "rmo", "dnw", "dew"
+      "usa", "ury", "rmo", "dnw", "dew",
+      "aut","aze", # New in 2023
+      "bfl","bih", 
+      "cyp", 
+      "esp", 
+      "grc", 
+      "hun", 
+      "lva", 
+      "mlt", 
+      "omn", 
+      "rou", 
+      "srb","swe", 
+      "twn", 
+      "xkx" 
     ),
     cntryName = c(
       "Buenos Aires, Argentina", "Australia",
@@ -709,14 +724,27 @@ getICILSCountryName <- function(countryCode) {
       "Slovak Republic", "Slovenia",
       "Thailand", "Turkey",
       "Finland", "France", "Italy", "Kazakhstan", "Luxembourg", "Portugal",
-      "United States", "Uruguay", "Moscow (Russian Federation)", "North Rhine-Westphalia (Germany)", "Germany - DEU and NRW"
+      "United States", "Uruguay", "Moscow (Russian Federation)", "North Rhine-Westphalia (Germany)", "Germany - DEU and NRW",
+      "Austria", "Azerbaijan", # New in 2023
+      "Belgium (Flanders)", "Bosnia and Herzegovina", 
+      "Cyprus", 
+      "Spain", 
+      "Greece", 
+      "Hungary", 
+      "Latvia", 
+      "Malta", 
+      "Oman", 
+      "Romania", 
+      "Serbia", "Sweden", 
+      "Taiwan", 
+      "Kosovo"
     ),
     stringsAsFactors = FALSE
   ) # be sure to not create any factors not needed at all
 
   lookupNames <- vector(mode = "character", length = length(countryCode))
 
-  for (i in 1:length(countryCode)) {
+  for (i in seq_along(countryCode)) {
     testName <- cntryCodeDF[cntryCodeDF$cntryCode == countryCode[i], "cntryName"]
 
     if (length(testName) == 0) { # test if no value found
