@@ -202,7 +202,7 @@ read_ePIRLS <- function(path,
       testJKprefix <- c("JK", "JK.TCHWGT") # have any jk prefix values here that are applicable for this dataset
       weights <- NULL # default value
 
-      for (i in 1:length(testJKprefix)) {
+      for (i in seq_along(testJKprefix)) {
         ujkz <- unique(tolower(grep(paste0("^", "(", testJKprefix[i], ")", "[1-9]"), c(names(processedData$dataList$student), names(processedData$dataList$teacher)), value = TRUE, ignore.case = TRUE)))
         ujkz <- gsub(tolower(testJKprefix[i]), "", ujkz, fixed = TRUE) # remove jk to leave the numeric values
 
@@ -586,7 +586,7 @@ export_ePIRLSToCSV <- function(folderPath, exportPath, cntryCodes, ...) {
   sdfList <- read_ePIRLS(folderPath, cntryCodes, ...)
 
   if (inherits(sdfList, "edsurvey.data.frame.list")) {
-    for (i in 1:length(sdfList$datalist)) {
+    for (i in seq_along(sdfList$datalist)) {
       sdf <- sdfList$datalist[[i]]
       cntry <- sdf$country
 
@@ -644,7 +644,7 @@ get_ePIRLSCountryName <- function(countryCode) {
 
   lookupNames <- vector(mode = "character", length = length(countryCode))
 
-  for (i in 1:length(countryCode)) {
+  for (i in seq_along(countryCode)) {
     testName <- cntryCodeDF[cntryCodeDF$cntryCode == countryCode[i], "cntryName"]
 
     if (length(testName) == 0) { # test if no value found
