@@ -1,9 +1,9 @@
 \dontrun{
 # read in the example data (generated, not real student data)
-sdf <- readNAEP(system.file("extdata/data", "M36NT2PM.dat", package = "NAEPprimer"))
+sdf <- readNAEP(path=system.file("extdata/data", "M36NT2PM.dat", package = "NAEPprimer"))
 
 # use | symbol to separate dependent variables in the left-hand side of formula
-mvrlm.fit <- mvrlm.sdf(algebra | geometry ~ dsex + m072801, jrrIMax = 5, data = sdf)
+mvrlm.fit <- mvrlm.sdf(formula=algebra | geometry ~ dsex + m072801, jrrIMax = 5, data = sdf)
 
 # print method returns coefficients, as does coef method
 mvrlm.fit
@@ -25,22 +25,23 @@ mvrlm.fit$residCov
 
 # dependent variables can have plausible values or not (or a combination)
 
-mvrlm.fit <- mvrlm.sdf(composite | mrps22 ~ dsex + m072801, data = sdf, jrrIMax = 5)
+mvrlm.fit <- mvrlm.sdf(formula=composite | mrps22 ~ dsex + m072801, data = sdf, jrrIMax = 5)
 summary(mvrlm.fit)
 
-mvrlm.fit <- mvrlm.sdf(algebra | geometry | measurement ~ dsex + m072801, data = sdf, jrrIMax = 5)
+mvrlm.fit <- mvrlm.sdf(formula=algebra | geometry | measurement ~ dsex + m072801,
+	                   data = sdf, jrrIMax = 5)
 summary(mvrlm.fit)
 
-mvrlm.fit <- mvrlm.sdf(mrps51 | mrps22 ~ dsex + m072801, data = sdf, jrrIMax = 5)
+mvrlm.fit <- mvrlm.sdf(formula=mrps51 | mrps22 ~ dsex + m072801, data = sdf, jrrIMax = 5)
 summary(mvrlm.fit)
 
 # hypotheses about coefficient restrictions can also be tested using the Wald test
 
-mvr <- mvrlm.sdf(algebra | geometry ~ dsex + m072801, data = sdf)
+mvr <- mvrlm.sdf(formula=algebra | geometry ~ dsex + m072801, data = sdf)
 
 hypothesis <- c("geometry_dsexFemale = 0", "algebra_dsexFemale = 0")
 
 # test statistics based on the F and chi-squared distribution are available
-linearHypothesis(mvr, hypothesis = hypothesis, test = "F")
-linearHypothesis(mvr, hypothesis = hypothesis, test = "Chisq")
+linearHypothesis(model=mvr, hypothesis = hypothesis, test = "F")
+linearHypothesis(model=mvr, hypothesis = hypothesis, test = "Chisq")
 }
