@@ -1,7 +1,7 @@
 \dontrun{
 # read-in student file with defaults
 eclsk_df <- readECLS_K2011(path="~/ECLS_K/2011") #using defaults
-d <- getData(eclsk_df, c("childid", "c1hgt1", "c1wgt1"))
+d <- getData(data=eclsk_df, varnames=c("childid", "c1hgt1", "c1wgt1"))
 summary(d)
 }
 
