@@ -1,7 +1,7 @@
 \dontrun{
 eng <- readCivEDICCS("~/ICCS/2009/", countries = c("eng"),
                      gradeLvl = 8, dataSet = "student")
-gg <- getData(eng, c("famstruc", "totwgts", "civ"))
+gg <- getData(getData=eng, varnames=c("famstruc", "totwgts", "civ"))
 head(gg)
-edsurveyTable(civ ~ famstruc, eng)
+edsurveyTable(formula=civ ~ famstruc, data=eng)
 }
