@@ -3,11 +3,11 @@
 can <- readPIAAC("~/PIAAC/Cycle 1/", countries = "can")
 
 # extract a data.frame with a few variables
-gg <- getData(can, c("c_d05","ageg10lfs"))  
+gg <- getData(data=can, varnames=c("c_d05","ageg10lfs"))  
 head(gg)
 
 # conduct an analysis on the edsurvey.data.frame
-edsurveyTable(~ c_d05 + ageg10lfs, data = can)
+edsurveyTable(formula=~ c_d05 + ageg10lfs, data = can)
 
 # the following call returns an edsurvey.data.frame to PIAAC for Canada
 can <- readPIAAC("~/PIAAC/Cycle 1/", countries = "can", us)
