@@ -1,19 +1,19 @@
 \dontrun{
 # read in the example data (generated, not real student data)
-sdf <- readNAEP(system.file("extdata/data", "M36NT2PM.dat", package="NAEPprimer"))
+sdf <- readNAEP(path=system.file("extdata/data", "M36NT2PM.dat", package="NAEPprimer"))
 
 # search both the student and school files, returning levels for variable values
-showCodebook(sdf, c("student","school"), labelLevels = TRUE, includeRecodes = FALSE)
+showCodebook(data=sdf, fileFormat=c("student","school"), labelLevels = TRUE, includeRecodes = FALSE)
 
 # return codebook information for the student file, excluding variable value levels,
 # including recoded variables
 sdf <- recode.sdf(sdf, recode = list(dsex = list(from = c("Male"), to = c("MALE"))))
-showCodebook(sdf, c("student"), labelLevels = FALSE, includeRecodes = TRUE)
+showCodebook(data=sdf, fileFormat=c("student"), labelLevels = FALSE, includeRecodes = TRUE)
 
 # return codebook information for the student file, including variable value levels
 # and recoded variables
-showCodebook(sdf, c("student","school"), labelLevels = FALSE, includeRecodes = TRUE)
+showCodebook(data=sdf, fileFormat=c("student","school"), labelLevels = FALSE, includeRecodes = TRUE)
 
 # return codebook information for all codebooks in an edsurvey.data.frame; commonly use View()
-View(showCodebook(sdf))
+View(showCodebook(data=sdf))
 }
