@@ -359,7 +359,7 @@ estwith0REF <- c(
   "",
   "Formula: composite ~ b003501 + m815401 ",
   "",
-  "Plausible values: 5",
+  "Plausible values: 5", 
   "jrrIMax: 1",
   "Weight variable: 'origwt'",
   "Variance method: jackknife",
@@ -369,44 +369,45 @@ estwith0REF <- c(
   "",
   "",
   "Summary Table:",
-  "             b003501            m815401    N     WTD_N         PCT     SE(PCT)     MEAN  SE(MEAN)",
-  " Did not finish H.S. Easier than others  860  941.6337 49.83286267  1.64889511 268.3298  1.803212",
-  " Did not finish H.S.  As hard as others  610  660.9430 34.97823171  1.80714925 260.0554  2.031126",
-  " Did not finish H.S. Harder than others  158  161.3728  8.54012402  0.73901762 255.5587  2.911688",
-  " Did not finish H.S.        Much harder   71   67.3144  3.56239295  0.57731370 237.5406  7.030221",
-  " Did not finish H.S.            Omitted   47   54.7796  2.89902993  0.59089141 237.9851  6.155979",
-  " Did not finish H.S.           Multiple    2    3.5403  0.18735872  0.13696789 241.7904 10.080054",
-  "      Graduated H.S. Easier than others 1755 1836.0455 51.02778274  1.21872773 275.0705  1.128695",
-  "      Graduated H.S.  As hard as others 1211 1222.7080 33.98177125  1.19322392 267.7533  1.180079",
-  "      Graduated H.S. Harder than others  334  332.6968  9.24638307  0.67937504 263.6961  2.648693",
-  "      Graduated H.S.        Much harder  101  106.5451  2.96112499  0.45568508 237.5003  5.862016",
-  "      Graduated H.S.            Omitted   99   97.2152  2.70182635  0.42176804 254.6397  5.727409",
-  "      Graduated H.S.           Multiple    4    2.9185  0.08111160  0.05140085 255.7386 16.510320",
-  "  Some ed after H.S. Easier than others 1479 1558.4164 53.88140863  1.28505307 290.1307  1.112578",
-  "  Some ed after H.S.  As hard as others 1064 1015.5016 35.11042150  1.29074248 278.2807  1.266867",
-  "  Some ed after H.S. Harder than others  250  208.7832  7.21856682  0.59140478 269.7629  3.847818",
-  "  Some ed after H.S.        Much harder   57   47.6512  1.64751460  0.30681445 254.0030  6.018615",
-  "  Some ed after H.S.            Omitted   69   60.6641  2.09742862  0.39367631 263.6685  4.516513",
-  "  Some ed after H.S.           Multiple    2    1.2917  0.04465983  0.04026678 251.3682  7.558644",
-  "        I Don't Know Easier than others 1078 1204.2905 46.34193654  1.44483641 264.6348  1.749268",
-  "        I Don't Know  As hard as others  868  928.3830 35.72482393  1.24387807 256.7520  1.884006",
-  "        I Don't Know Harder than others  274  273.8016 10.53607611  0.71134338 255.4384  2.958810",
-  "        I Don't Know        Much harder  103   89.4648  3.44266777  0.46714337 243.9997  4.759095",
-  "        I Don't Know            Omitted   93  101.9524  3.92319930  0.56310218 237.8497  3.975815",
-  "        I Don't Know           Multiple    1    0.8133  0.03129635  0.03132223 292.2200        NA",
-  "             Omitted Easier than others   31   37.3172 17.01982100  3.41767224 286.8190  8.815679",
-  "             Omitted  As hard as others   29   27.4135 12.50289044  3.13717532 258.3821  7.985184",
-  "             Omitted Harder than others    7    5.5018  2.50928931  1.09558321 252.8294 32.209054",
-  "             Omitted        Much harder    4    5.9324  2.70567958  1.49181111 249.4781  8.429959",
-  "             Omitted            Omitted  531  143.0924 65.26231966  4.35263126 252.1139  3.665201",
-  "             Omitted           Multiple    0    0.0000  0.00000000          NA       NA        NA",
-  "            Multiple Easier than others   13    8.0853 32.81531568 12.57870084 252.9200  8.349768",
-  "            Multiple  As hard as others   13   13.8744 56.31118399  9.39004975 251.1944  7.175494",
-  "            Multiple Harder than others    0    0.0000  0.00000000          NA       NA        NA",
-  "            Multiple        Much harder    1    0.1435  0.58241473  0.61353570 240.2340        NA",
-  "            Multiple            Omitted    1    2.5356 10.29108560 10.49245307 280.2800        NA",
+  "             b003501            m815401    N     WTD_N         PCT     SE(PCT)     MEAN  SE(MEAN)", 
+  " Did not finish H.S. Easier than others  860  941.6337 49.83286267  1.64889511 268.3298  1.803212", 
+  " Did not finish H.S.  As hard as others  610  660.9430 34.97823171  1.80714925 260.0554  2.031126", 
+  " Did not finish H.S. Harder than others  158  161.3728  8.54012402  0.73901762 255.5587  2.911688", 
+  " Did not finish H.S.        Much harder   71   67.3144  3.56239295  0.57731370 237.5406  7.030221", 
+  " Did not finish H.S.            Omitted   47   54.7796  2.89902993  0.59089141 237.9851  6.155979", 
+  " Did not finish H.S.           Multiple    2    3.5403  0.18735872  0.13696789 241.7904 10.080054", 
+  "      Graduated H.S. Easier than others 1755 1836.0455 51.02778274  1.21872773 275.0705  1.128695", 
+  "      Graduated H.S.  As hard as others 1211 1222.7080 33.98177125  1.19322392 267.7533  1.180079", 
+  "      Graduated H.S. Harder than others  334  332.6968  9.24638307  0.67937504 263.6961  2.648693", 
+  "      Graduated H.S.        Much harder  101  106.5451  2.96112499  0.45568508 237.5003  5.862016", 
+  "      Graduated H.S.            Omitted   99   97.2152  2.70182635  0.42176804 254.6397  5.727409", 
+  "      Graduated H.S.           Multiple    4    2.9185  0.08111160  0.05140085 255.7386 16.510320", 
+  "  Some ed after H.S. Easier than others 1479 1558.4164 53.88140863  1.28505307 290.1307  1.112578", 
+  "  Some ed after H.S.  As hard as others 1064 1015.5016 35.11042150  1.29074248 278.2807  1.266867", 
+  "  Some ed after H.S. Harder than others  250  208.7832  7.21856682  0.59140478 269.7629  3.847818", 
+  "  Some ed after H.S.        Much harder   57   47.6512  1.64751460  0.30681445 254.0030  6.018615", 
+  "  Some ed after H.S.            Omitted   69   60.6641  2.09742862  0.39367631 263.6685  4.516513", 
+  "  Some ed after H.S.           Multiple    2    1.2917  0.04465983  0.04026678 251.3682  7.558644", 
+  "        I Don't Know Easier than others 1078 1204.2905 46.34193654  1.44483641 264.6348  1.749268", 
+  "        I Don't Know  As hard as others  868  928.3830 35.72482393  1.24387807 256.7520  1.884006", 
+  "        I Don't Know Harder than others  274  273.8016 10.53607611  0.71134338 255.4384  2.958810", 
+  "        I Don't Know        Much harder  103   89.4648  3.44266777  0.46714337 243.9997  4.759095", 
+  "        I Don't Know            Omitted   93  101.9524  3.92319930  0.56310218 237.8497  3.975815", 
+  "        I Don't Know           Multiple    1    0.8133  0.03129635  0.03132223 292.2200        NA", 
+  "             Omitted Easier than others   31   37.3172 17.01982100  3.41767224 286.8190  8.815679", 
+  "             Omitted  As hard as others   29   27.4135 12.50289044  3.13717532 258.3821  7.985184", 
+  "             Omitted Harder than others    7    5.5018  2.50928931  1.09558321 252.8294 32.209054", 
+  "             Omitted        Much harder    4    5.9324  2.70567958  1.49181111 249.4781  8.429959", 
+  "             Omitted            Omitted  531  143.0924 65.26231966  4.35263126 252.1139  3.665201", 
+  "             Omitted           Multiple    0    0.0000  0.00000000          NA       NA        NA", 
+  "            Multiple Easier than others   13    8.0853 32.81531568 12.57870084 252.9200  8.349768", 
+  "            Multiple  As hard as others   13   13.8744 56.31118399  9.39004975 251.1944  7.175494", 
+  "            Multiple Harder than others    0    0.0000  0.00000000          NA       NA        NA", 
+  "            Multiple        Much harder    1    0.1435  0.58241473  0.61353570 240.2340        NA", 
+  "            Multiple            Omitted    1    2.5356 10.29108560 10.49245307 280.2800        NA", 
   "            Multiple           Multiple    0    0.0000  0.00000000          NA       NA        NA"
 )
+
 logit1REF <- c(
   "",
   "Formula: I(composite > 300) ~ dsex + b013801",
@@ -440,12 +441,12 @@ gap0REF <- c(
   "     B                 default     17606 16915",
   "",
   "Percentage:",
-  "       pctA     pctAse     dofA pctB pctBse dofB    diffAB covAB   diffABse diffABpValue    dofAB",
-  " 0.09917399 0.03155192 12.84562  100      0    0 -99.90083     0 0.03155192            0 12.84562",
+  "       pctA   pctAse   dofA pctB pctBse dofB  diffAB covAB diffABse diffABpValue  dofAB",
+  " 0.09917399 0.031552 12.846  100      0    0 -99.901     0 0.031552    < 2.2e-16 12.846",
   "",
   "Results:",
-  " estimateA estimateAse dofA estimateB estimateBse     dofB     diffAB        covAB diffABse diffABpValue dofAB",
-  "         0          NA   NA 0.2195458  0.06638235 9.756959 -0.2195458 4.505231e-06       NA           NA    NA"
+  " estimateA estimateAse dofA estimateB estimateBse  dofB  diffAB covAB diffABse diffABpValue dofAB",
+  "         0          NA   NA    0.2195      0.0664 9.757 -0.2195     0       NA           NA    NA"
 )
 wt1REF <- c(
   "Wald test:",
@@ -543,20 +544,21 @@ dplO <- c(
   ""
 )
 gapPSUREF <- c(
-  "Call: gap(variable = \"composite\", data = sdf, groupA = dsex %in% \"Male\", ",
-  "    groupB = dsex %in% \"Female\", returnNumberOfPSU = TRUE)",
+  "Call: gap(variable = \"composite\", data = sdf, groupA = dsex %in% \"Male\", ", 
+  "    groupB = dsex %in% \"Female\", returnNumberOfPSU = TRUE)", 
   "",
   "Labels:",
-  " group         definition nFullData nUsed nPSU",
+  " group         definition nFullData nUsed nPSU", 
   "     A   dsex %in% \"Male\"     17606  8486  124",
-  "     B dsex %in% \"Female\"     17606  8429  124",
+  "     B dsex %in% \"Female\"     17606  8429  124", 
   "",
   "Percentage:",
-  "     pctA    pctAse     pctB    pctBse    diffAB      covAB diffABse diffABpValue    dofAB",
-  " 50.27015 0.5016796 49.72985 0.5016796 0.5402935 -0.2516824 1.003359    0.5924778 53.45667", "",
+  "     pctA  pctAse  pctB  pctBse  diffAB    covAB diffABse diffABpValue  dofAB", 
+  " 50.27015 0.50168 49.73 0.50168 0.54029 -0.25168   1.0034       0.5925 53.457", 
+  "",
   "Results:",
-  " estimateA estimateAse estimateB estimateBse   diffAB     covAB  diffABse diffABpValue    dofAB",
-  "  276.7235   0.8207151  275.0458   0.9402535 1.677756 0.5676583 0.6498719   0.01259479 53.70969"
+  " estimateA estimateAse estimateB estimateBse diffAB   covAB diffABse diffABpValue dofAB", 
+  "  276.7235     0.82071    275.05     0.94025 1.6778 0.56766  0.64987      0.01259 53.71"
 )
 sPV_wREF <- c(
   "Estimates are weighted using the weight variable 'origwt'",
@@ -796,3 +798,284 @@ pdf_estREF <- c(
   "\\end{tabular}",
   "\\end{table}"
 )
+
+lm10_head <- 
+list(formula = composite ~ dsex + b017451, coef = c(`(Intercept)` = 270.411120956747, 
+dsexFemale = -2.95857830863405, `b017451Once every few weeks` = 4.23341438050276, 
+`b017451About once a week` = 11.2261231533783, `b0174512 or 3 times a week` = 14.9459085095952, 
+`b017451Every day` = 7.52998369846192), se = c(`(Intercept)` = 1.02443397803618, 
+dsexFemale = 0.604228514050488, `b017451Once every few weeks` = 1.18326707469577, 
+`b017451About once a week` = 1.25853689767647, `b0174512 or 3 times a week` = 1.18664605765311, 
+`b017451Every day` = 1.3084557511019), Vimp = c(`(Intercept)` = 0.0317123088999927, 
+dsexFemale = 0.0118044139976679, `b017451Once every few weeks` = 0.115883064314653, 
+`b017451About once a week` = 0.249949470571965, `b0174512 or 3 times a week` = 0.0621448682665872, 
+`b017451Every day` = 0.216972364588427), Vjrr = c(`(Intercept)` = 1.01775266645504, 
+dsexFemale = 0.353287683193993, `b017451Once every few weeks` = 1.28423790574442, 
+`b017451About once a week` = 1.33396565224115, `b0174512 or 3 times a week` = 1.34598399787709, 
+`b017451Every day` = 1.4950840880032), M = 5L, varm = structure(c(1.01775266645504, 
+0.353287683193993, 1.28423790574442, 1.33396565224115, 1.34598399787709, 
+1.4950840880032), dim = c(1L, 6L)), coefm = structure(c(270.299026109663, 
+270.3698547706, 270.358978287715, 270.697727097624, 270.330018518134, 
+-2.93888691554455, -3.03862500768519, -2.82749375810408, -3.0741562379871, 
+-2.91372962384933, 4.38903707262901, 4.32933570873935, 3.8893149993103, 
+3.9404503137907, 4.61893380804442, 11.4467530795666, 11.2824696023128, 
+11.5962902897723, 10.4362406942504, 11.3688621009895, 15.3123206803453, 
+14.9766415511688, 14.8990230698195, 14.7059405034579, 14.8356167431845, 
+7.99325875545627, 7.40171989229546, 7.73429696289416, 6.8698176274791, 
+7.65082525418462), dim = 5:6, dimnames = list(NULL, c("(Intercept)", 
+"dsexFemale", "b017451Once every few weeks", "b017451About once a week", 
+"b0174512 or 3 times a week", "b017451Every day"))), coefmat = structure(list(
+    coef = c(270.411120956747, -2.95857830863405, 4.23341438050276, 
+    11.2261231533783, 14.9459085095952, 7.52998369846192), se = c(1.02443397803618, 
+    0.604228514050488, 1.18326707469577, 1.25853689767647, 1.18664605765311, 
+    1.3084557511019), t = c(263.961491666959, -4.89645595968488, 
+    3.57773360810468, 8.91997936183212, 12.5950854622603, 5.75486308354001
+    ), dof = c(54.6700206144557, 54.9911209627616, 57.3160571925223, 
+    54.6832034093795, 72.5820287251234, 48.4697539222567), `Pr(>|t|)` = c(0, 
+    8.94739811057101e-06, 0.00071311498547777, 2.98339131177272e-12, 
+    0, 5.75502820066021e-07)), row.names = c("(Intercept)", "dsexFemale", 
+"b017451Once every few weeks", "b017451About once a week", "b0174512 or 3 times a week", 
+"b017451Every day"), class = "data.frame"), r.squared = 0.0223931751818003, 
+    weight = "origwt", npv = 5L, jrrIMax = 1, njk = 62L, varMethod = "jackknife", 
+    residuals = structure(c(40.0688953447908, 9.75133419850852, 
+    67.7374736534249, 70.8188953447908, 6.75404297138402, 42.5929705336575, 
+    25.7388953447908, 5.25133419850852, 63.0474736534248, 43.8488953447908, 
+    -26.605957028616, 53.2329705336575, 18.6688953447908, 1.7713341985085, 
+    54.4974736534249, 49.9288953447908, -8.68595702861597, 42.7129705336575, 
+    51.0288953447908, 11.3513341985085, 77.4774736534249, 55.4088953447908, 
+    5.81404297138403, 48.7129705336575, 37.7588953447908, 7.55133419850853, 
+    67.2774736534249, 49.3788953447908, 13.354042971384, 34.6629705336575
+    ), dim = 6:5), fitted.values = c(277.941104655209, 278.678665801491, 
+    274.982526346575, 277.941104655209, 271.685957028616, 285.357029466342
+    ), residual.df = 16325L, PV.residuals = structure(c(39.7177151348806, 
+    9.62310772631491, 67.3666020504252, 70.4677151348806, 6.69082373325244, 
+    42.3386532099916, 25.9084253371047, 5.31630063477252, 63.2970503447899, 
+    44.0184253371047, -26.580565471654, 53.2435036782313, 18.5167247493907, 
+    1.32222518061661, 54.2142185074948, 49.7767247493907, -8.42079952892141, 
+    42.8119986424654, 51.4024552748965, 11.9701884461122, 77.9666115128836, 
+    55.7824552748965, 5.93597882657201, 48.6663323989176, 37.7191562276816, 
+    7.44484900472605, 67.1928858515309, 49.3391562276816, 13.0047772976712, 
+    34.8543647386817), dim = 6:5), PV.fitted.values = structure(c(278.292284865119, 
+    278.806892273685, 275.353397949575, 278.292284865119, 271.749176266748, 
+    285.611346790008, 277.771574662895, 278.613699365227, 274.73294965521, 
+    277.771574662895, 271.660565471654, 285.346496321769, 278.093275250609, 
+    279.127774819383, 275.265781492505, 278.093275250609, 271.420799528921, 
+    285.258001357535, 277.567544725104, 278.059811553888, 274.493388487116, 
+    277.567544725104, 271.564021173428, 285.403667601082, 277.980843772318, 
+    278.785150995274, 275.067114148469, 277.980843772318, 272.035222702329, 
+    285.165635261318), dim = 6:5), B = structure(c(0.0264269240833273, 
+    -0.0106254655135796, -0.029673103849521, -0.0710799558654692, 
+    -0.0249319481634757, -0.0640748555734966, -0.0106254655135796, 
+    0.00983701166472321, 0.000357587169684912, 0.0365129972962016, 
+    0.00534942383801708, 0.031973037584361, -0.029673103849521, 
+    0.000357587169684912, 0.0965692202622109, 0.0497003453877256, 
+    0.0259714094329351, 0.0573701283243995, -0.0710799558654692, 
+    0.0365129972962016, 0.0497003453877256, 0.208291225476638, 
+    0.0597553317741062, 0.177329395929916, -0.0249319481634757, 
+    0.00534942383801708, 0.0259714094329351, 0.0597553317741062, 
+    0.051787390222156, 0.0753298180705498, -0.0640748555734966, 
+    0.031973037584361, 0.0573701283243995, 0.177329395929916, 
+    0.0753298180705498, 0.180810303823689), dim = c(6L, 6L), dimnames = list(
+        c("(Intercept)", "dsexFemale", "b017451Once every few weeks", 
+        "b017451About once a week", "b0174512 or 3 times a week", 
+        "b017451Every day"), c("(Intercept)", "dsexFemale", "b017451Once every few weeks", 
+        "b017451About once a week", "b0174512 or 3 times a week", 
+        "b017451Every day"))), U = structure(c(1.01775266645504, 
+    -0.0539588947946272, -0.68525863004781, -0.466713890727058, 
+    -0.428898034193583, -0.568765736440115, -0.0539588947946272, 
+    0.353287683193993, -0.134920749671854, -0.0520955931471992, 
+    -0.0159324173319144, -0.11263633925747, -0.68525863004781, 
+    -0.134920749671854, 1.28423790574442, 0.736185103282417, 
+    0.594797632018768, 0.686080650535171, -0.466713890727058, 
+    -0.0520955931471992, 0.736185103282417, 1.33396565224115, 
+    0.63980493976393, 0.729477596903082, -0.428898034193583, 
+    -0.0159324173319144, 0.594797632018768, 0.63980493976393, 
+    1.34598399787709, 0.4810029673653, -0.568765736440115, -0.11263633925747, 
+    0.686080650535171, 0.729477596903082, 0.4810029673653, 1.4950840880032
+    ), dim = c(6L, 6L), dimnames = list(c("(Intercept)", "dsexFemale", 
+    "b017451Once every few weeks", "b017451About once a week", 
+    "b0174512 or 3 times a week", "b017451Every day"), c("(Intercept)", 
+    "dsexFemale", "b017451Once every few weeks", "b017451About once a week", 
+    "b0174512 or 3 times a week", "b017451Every day"))), rbar = 0.0857835117931858, 
+    Ttilde = structure(c(1.10505906432044, -0.0585876782825894, 
+    -0.744042521819899, -0.506750247276286, -0.465690413767903, 
+    -0.617556458699585, -0.0585876782825894, 0.383593941331652, 
+    -0.146494725392475, -0.056564536076315, -0.0172991560420006, 
+    -0.122298679994505, -0.744042521819899, -0.146494725392475, 
+    1.39440434327711, 0.799337646771812, 0.645821461699609, 0.744935058111432, 
+    -0.506750247276286, -0.056564536076315, 0.799337646771812, 
+    1.44839791050188, 0.694689654359507, 0.792054746939883, -0.465690413767903, 
+    -0.0172991560420006, 0.645821461699609, 0.694689654359507, 
+    1.46144723203242, 0.522265091088839, -0.617556458699585, 
+    -0.122298679994505, 0.744935058111432, 0.792054746939883, 
+    0.522265091088839, 1.62333765149823), dim = c(6L, 6L), dimnames = list(
+        c("(Intercept)", "dsexFemale", "b017451Once every few weeks", 
+        "b017451About once a week", "b0174512 or 3 times a week", 
+        "b017451Every day"), c("(Intercept)", "dsexFemale", "b017451Once every few weeks", 
+        "b017451About once a week", "b0174512 or 3 times a week", 
+        "b017451Every day"))), waldDenomBaseDof = 63, n0 = 17606L, 
+    nUsed = 16331L, Xstdev = list(outcome.std = 36.3450748753527, 
+        `(Intercept)` = 0, dsexFemale = 0.500012547576328, `b017451Once every few weeks` = 0.392880957783438, 
+        `b017451About once a week` = 0.380480563361107, `b0174512 or 3 times a week` = 0.403543023481001), 
+    varSummary = list(structure(list(summary = structure(list(
+        Variable = c("mrpcm1", "mrpcm2", "mrpcm3", "mrpcm4", 
+        "mrpcm5"), N = c(16331, 16331, 16331, 16331, 16331), 
+        Min. = c(130.53, 124.16, 115.09, 137.19, 123.58), `1st Qu.` = c(252.451666666667, 
+        252.691666666667, 252.371666666667, 252.815, 252.86), 
+        Median = c(277.5, 277.5, 277.47, 277.64, 277.33), Mean = c(276.139280509461, 
+        275.92952544241, 275.934778029514, 276.016936501133, 
+        275.980287796216), `3rd Qu.` = c(300.798333333333, 300.76, 
+        300.678333333333, 300.828333333333, 300.61), Max. = c(410.8, 
+        408.58, 398.17, 407.41, 395.96), SD = c(35.694086381693, 
+        35.8508676252172, 35.9087308785062, 35.7219798072453, 
+        35.8801154841422), `NA's` = c(0, 0, 0, 0, 0)), class = "data.frame", row.names = c(NA, 
+    -5L))), class = "summary2"), structure(list(summary = structure(list(
+        dsex = structure(1:2, levels = c("Male", "Female"), class = "factor"), 
+        N = c(8163L, 8168L), Percent = c(49.9846916906497, 50.0153083093503
+        )), row.names = c(NA, -2L), class = "data.frame")), class = "summary2"), 
+        structure(list(summary = structure(list(b017451 = structure(1:5, levels = c("Never or hardly ever", 
+        "Once every few weeks", "About once a week", "2 or 3 times a week", 
+        "Every day"), class = "factor"), N = c(3837L, 3147L, 
+        2853L, 3362L, 3132L), Percent = c(23.495193190864, 19.270099810177, 
+        17.4698426305799, 20.5866144143041, 19.1782499540751)), row.names = c(NA, 
+        -5L), class = "data.frame")), class = "summary2")))
+
+lm1_head <- list(formula = composite ~ dsex + b017451, coef = c(`(Intercept)` = 270.411120956747, 
+dsexFemale = -2.95857830863405, `b017451Once every few weeks` = 4.23341438050276, 
+`b017451About once a week` = 11.2261231533783, `b0174512 or 3 times a week` = 14.9459085095952, 
+`b017451Every day` = 7.52998369846192), se = c(`(Intercept)` = 1.02443397803618, 
+dsexFemale = 0.604228514050488, `b017451Once every few weeks` = 1.18326707469577, 
+`b017451About once a week` = 1.25853689767647, `b0174512 or 3 times a week` = 1.18664605765311, 
+`b017451Every day` = 1.3084557511019), Vimp = c(`(Intercept)` = 0.0317123088999927, 
+dsexFemale = 0.0118044139976679, `b017451Once every few weeks` = 0.115883064314653, 
+`b017451About once a week` = 0.249949470571965, `b0174512 or 3 times a week` = 0.0621448682665872, 
+`b017451Every day` = 0.216972364588427), Vjrr = c(`(Intercept)` = 1.01775266645504, 
+dsexFemale = 0.353287683193993, `b017451Once every few weeks` = 1.28423790574442, 
+`b017451About once a week` = 1.33396565224115, `b0174512 or 3 times a week` = 1.34598399787709, 
+`b017451Every day` = 1.4950840880032), M = 5L, varm = structure(c(1.01775266645504, 
+0.353287683193993, 1.28423790574442, 1.33396565224115, 1.34598399787709, 
+1.4950840880032), dim = c(1L, 6L)), coefm = structure(c(270.299026109663, 
+270.3698547706, 270.358978287715, 270.697727097624, 270.330018518134, 
+-2.93888691554455, -3.03862500768519, -2.82749375810408, -3.0741562379871, 
+-2.91372962384933, 4.38903707262901, 4.32933570873935, 3.8893149993103, 
+3.9404503137907, 4.61893380804442, 11.4467530795666, 11.2824696023128, 
+11.5962902897723, 10.4362406942504, 11.3688621009895, 15.3123206803453, 
+14.9766415511688, 14.8990230698195, 14.7059405034579, 14.8356167431845, 
+7.99325875545627, 7.40171989229546, 7.73429696289416, 6.8698176274791, 
+7.65082525418462), dim = 5:6, dimnames = list(NULL, c("(Intercept)", 
+"dsexFemale", "b017451Once every few weeks", "b017451About once a week", 
+"b0174512 or 3 times a week", "b017451Every day"))), coefmat = structure(list(
+    coef = c(270.411120956747, -2.95857830863405, 4.23341438050276, 
+    11.2261231533783, 14.9459085095952, 7.52998369846192), se = c(1.02443397803618, 
+    0.604228514050488, 1.18326707469577, 1.25853689767647, 1.18664605765311, 
+    1.3084557511019), t = c(263.961491666959, -4.89645595968488, 
+    3.57773360810468, 8.91997936183212, 12.5950854622603, 5.75486308354001
+    ), dof = c(54.6700206144557, 54.9911209627616, 57.3160571925223, 
+    54.6832034093795, 72.5820287251234, 48.4697539222567), `Pr(>|t|)` = c(0, 
+    8.94739811057101e-06, 0.00071311498547777, 2.98339131177272e-12, 
+    0, 5.75502820066021e-07)), row.names = c("(Intercept)", "dsexFemale", 
+"b017451Once every few weeks", "b017451About once a week", "b0174512 or 3 times a week", 
+"b017451Every day"), class = "data.frame"), r.squared = 0.0223931751818003, 
+    weight = "origwt", npv = 5L, jrrIMax = 1, njk = 62L, varMethod = "jackknife", 
+    residuals = structure(c(40.0688953447908, 9.75133419850852, 
+    67.7374736534249, 70.8188953447908, 6.75404297138402, 42.5929705336575, 
+    25.7388953447908, 5.25133419850852, 63.0474736534248, 43.8488953447908, 
+    -26.605957028616, 53.2329705336575, 18.6688953447908, 1.7713341985085, 
+    54.4974736534249, 49.9288953447908, -8.68595702861597, 42.7129705336575, 
+    51.0288953447908, 11.3513341985085, 77.4774736534249, 55.4088953447908, 
+    5.81404297138403, 48.7129705336575, 37.7588953447908, 7.55133419850853, 
+    67.2774736534249, 49.3788953447908, 13.354042971384, 34.6629705336575
+    ), dim = 6:5), fitted.values = c(277.941104655209, 278.678665801491, 
+    274.982526346575, 277.941104655209, 271.685957028616, 285.357029466342
+    ), residual.df = 16325L, PV.residuals = structure(c(39.7177151348806, 
+    9.62310772631491, 67.3666020504252, 70.4677151348806, 6.69082373325244, 
+    42.3386532099916, 25.9084253371047, 5.31630063477252, 63.2970503447899, 
+    44.0184253371047, -26.580565471654, 53.2435036782313, 18.5167247493907, 
+    1.32222518061661, 54.2142185074948, 49.7767247493907, -8.42079952892141, 
+    42.8119986424654, 51.4024552748965, 11.9701884461122, 77.9666115128836, 
+    55.7824552748965, 5.93597882657201, 48.6663323989176, 37.7191562276816, 
+    7.44484900472605, 67.1928858515309, 49.3391562276816, 13.0047772976712, 
+    34.8543647386817), dim = 6:5), PV.fitted.values = structure(c(278.292284865119, 
+    278.806892273685, 275.353397949575, 278.292284865119, 271.749176266748, 
+    285.611346790008, 277.771574662895, 278.613699365227, 274.73294965521, 
+    277.771574662895, 271.660565471654, 285.346496321769, 278.093275250609, 
+    279.127774819383, 275.265781492505, 278.093275250609, 271.420799528921, 
+    285.258001357535, 277.567544725104, 278.059811553888, 274.493388487116, 
+    277.567544725104, 271.564021173428, 285.403667601082, 277.980843772318, 
+    278.785150995274, 275.067114148469, 277.980843772318, 272.035222702329, 
+    285.165635261318), dim = 6:5), B = structure(c(0.0264269240833273, 
+    -0.0106254655135796, -0.029673103849521, -0.0710799558654692, 
+    -0.0249319481634757, -0.0640748555734966, -0.0106254655135796, 
+    0.00983701166472321, 0.000357587169684912, 0.0365129972962016, 
+    0.00534942383801708, 0.031973037584361, -0.029673103849521, 
+    0.000357587169684912, 0.0965692202622109, 0.0497003453877256, 
+    0.0259714094329351, 0.0573701283243995, -0.0710799558654692, 
+    0.0365129972962016, 0.0497003453877256, 0.208291225476638, 
+    0.0597553317741062, 0.177329395929916, -0.0249319481634757, 
+    0.00534942383801708, 0.0259714094329351, 0.0597553317741062, 
+    0.051787390222156, 0.0753298180705498, -0.0640748555734966, 
+    0.031973037584361, 0.0573701283243995, 0.177329395929916, 
+    0.0753298180705498, 0.180810303823689), dim = c(6L, 6L), dimnames = list(
+        c("(Intercept)", "dsexFemale", "b017451Once every few weeks", 
+        "b017451About once a week", "b0174512 or 3 times a week", 
+        "b017451Every day"), c("(Intercept)", "dsexFemale", "b017451Once every few weeks", 
+        "b017451About once a week", "b0174512 or 3 times a week", 
+        "b017451Every day"))), U = structure(c(1.01775266645504, 
+    -0.0539588947946272, -0.68525863004781, -0.466713890727058, 
+    -0.428898034193583, -0.568765736440115, -0.0539588947946272, 
+    0.353287683193993, -0.134920749671854, -0.0520955931471992, 
+    -0.0159324173319144, -0.11263633925747, -0.68525863004781, 
+    -0.134920749671854, 1.28423790574442, 0.736185103282417, 
+    0.594797632018768, 0.686080650535171, -0.466713890727058, 
+    -0.0520955931471992, 0.736185103282417, 1.33396565224115, 
+    0.63980493976393, 0.729477596903082, -0.428898034193583, 
+    -0.0159324173319144, 0.594797632018768, 0.63980493976393, 
+    1.34598399787709, 0.4810029673653, -0.568765736440115, -0.11263633925747, 
+    0.686080650535171, 0.729477596903082, 0.4810029673653, 1.4950840880032
+    ), dim = c(6L, 6L), dimnames = list(c("(Intercept)", "dsexFemale", 
+    "b017451Once every few weeks", "b017451About once a week", 
+    "b0174512 or 3 times a week", "b017451Every day"), c("(Intercept)", 
+    "dsexFemale", "b017451Once every few weeks", "b017451About once a week", 
+    "b0174512 or 3 times a week", "b017451Every day"))), rbar = 0.0857835117931858, 
+    Ttilde = structure(c(1.10505906432044, -0.0585876782825894, 
+    -0.744042521819899, -0.506750247276286, -0.465690413767903, 
+    -0.617556458699585, -0.0585876782825894, 0.383593941331652, 
+    -0.146494725392475, -0.056564536076315, -0.0172991560420006, 
+    -0.122298679994505, -0.744042521819899, -0.146494725392475, 
+    1.39440434327711, 0.799337646771812, 0.645821461699609, 0.744935058111432, 
+    -0.506750247276286, -0.056564536076315, 0.799337646771812, 
+    1.44839791050188, 0.694689654359507, 0.792054746939883, -0.465690413767903, 
+    -0.0172991560420006, 0.645821461699609, 0.694689654359507, 
+    1.46144723203242, 0.522265091088839, -0.617556458699585, 
+    -0.122298679994505, 0.744935058111432, 0.792054746939883, 
+    0.522265091088839, 1.62333765149823), dim = c(6L, 6L), dimnames = list(
+        c("(Intercept)", "dsexFemale", "b017451Once every few weeks", 
+        "b017451About once a week", "b0174512 or 3 times a week", 
+        "b017451Every day"), c("(Intercept)", "dsexFemale", "b017451Once every few weeks", 
+        "b017451About once a week", "b0174512 or 3 times a week", 
+        "b017451Every day"))), waldDenomBaseDof = 63, n0 = 17606L, 
+    nUsed = 16331L, Xstdev = list(outcome.std = 36.3450748753527, 
+        `(Intercept)` = 0, dsexFemale = 0.500012547576328, `b017451Once every few weeks` = 0.392880957783438, 
+        `b017451About once a week` = 0.380480563361107, `b0174512 or 3 times a week` = 0.403543023481001), 
+    varSummary = list(structure(list(summary = structure(list(
+        Variable = c("mrpcm1", "mrpcm2", "mrpcm3", "mrpcm4", 
+        "mrpcm5"), N = c(16331, 16331, 16331, 16331, 16331), 
+        Min. = c(130.53, 124.16, 115.09, 137.19, 123.58), `1st Qu.` = c(252.451666666667, 
+        252.691666666667, 252.371666666667, 252.815, 252.86), 
+        Median = c(277.5, 277.5, 277.47, 277.64, 277.33), Mean = c(276.139280509461, 
+        275.92952544241, 275.934778029514, 276.016936501133, 
+        275.980287796216), `3rd Qu.` = c(300.798333333333, 300.76, 
+        300.678333333333, 300.828333333333, 300.61), Max. = c(410.8, 
+        408.58, 398.17, 407.41, 395.96), SD = c(35.694086381693, 
+        35.8508676252172, 35.9087308785062, 35.7219798072453, 
+        35.8801154841422), `NA's` = c(0, 0, 0, 0, 0)), class = "data.frame", row.names = c(NA, 
+    -5L))), class = "summary2"), structure(list(summary = structure(list(
+        dsex = structure(1:2, levels = c("Male", "Female"), class = "factor"), 
+        N = c(8163L, 8168L), Percent = c(49.9846916906497, 50.0153083093503
+        )), row.names = c(NA, -2L), class = "data.frame")), class = "summary2"), 
+        structure(list(summary = structure(list(b017451 = structure(1:5, levels = c("Never or hardly ever", 
+        "Once every few weeks", "About once a week", "2 or 3 times a week", 
+        "Every day"), class = "factor"), N = c(3837L, 3147L, 
+        2853L, 3362L, 3132L), Percent = c(23.495193190864, 19.270099810177, 
+        17.4698426305799, 20.5866144143041, 19.1782499540751)), row.names = c(NA, 
+        -5L), class = "data.frame")), class = "summary2")))
